Installation
============

To install ``pysdic``, you can use the following command:

.. code-block:: bash

    pip install pysdic

Or install it directly from the GitHub repository using:

.. code-block:: bash

    pip install git+https://github.com/Artezaru/pysdic.git

Development Installation
------------------------------

To install the package for development, first clone the repository using:

.. code-block:: bash

    git clone https://github.com/Artezaru/pysdic.git

Then, go to the directory and run the following command:

.. code-block:: bash

    pip install -e .

Use ``-e .[dev]`` to install it with the development dependencies.

